@@ -26,9 +26,9 @@ def copy(filename: str, target: str = ".") -> None:
 class Test:
     """Test."""
 
-    #
     @pytest.mark.skipif(
-        sys.platform == "win32", reason="click cannot find bash in Windows"
+        sys.platform == "win32",
+        reason="bash is not installed in Windows be default",
     )
     def test_click(self, tmp_path: Path) -> None:
         """Test click. Check current directory.
